@@ -49,8 +49,8 @@ def Redondear(expr):#Redondeamos la expresión.
 
 
 def D(elemento,color = "black"):#Por default se imprime en rojo, para indicar que es un derivado.
-  global Documentos
-  
+  global Documento
+
   print("")
   Tipo = None
   if isinstance(elemento,sympy.core.relational.Equality):#Si el elemento ingresado es una ecuación, entonces la identificamos
